<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
	<xsl:output method="xml"/>
	<xsl:template match="/">
		<xsl:apply-templates select="//Package"/>
	</xsl:template>
	<xsl:template match="Package">
		<xsl:call-template name="CancleFligth"/>
	</xsl:template>
	<xsl:template name="CancleFligth">
		<ResultInformation xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<xsl:if test="count(//CANCELFLIGHT_ITEM)=0">
				<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'В пакете отсутствует документ Уведомление об отмене рейса. Необходимо добавить и заполнить такой документ.'"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:for-each select="//CANCELFLIGHT[position()=last()]/CANCELFLIGHT_ITEM">
				<xsl:variable name="Id" select="../@id"/>
				<xsl:variable name="Type" select="../@ctmtd:CfgName"/>
				<xsl:variable name="Pos" select="position()"/>
				<xsl:if test="string-length(RegDate)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'В документе Уведомление об отмене рейса не заполнена Дата и время документа.'"/>
						<xsl:with-param name="DocId" select="$Id"/>
						<xsl:with-param name="PathErr" select="'EDTRANSIT_DATELIMIT/EDTRANSIT_DATELIMIT_ITEM/RegDate'"/>
						<xsl:with-param name="TypeDoc" select="$Type"/>
						<xsl:with-param name="PosPkg" select="$Pos"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:for-each>	
			<xsl:if test="count(//GENERALDECLAIR_ITEM)=0 and count(//CANCELFLIGHT_ITEM)>0">
				<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'Для отправки Уведомления об отмене рейса в пакете документов на воздушное судно должен быть документ Генеральная/Общая декларация.'"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:for-each select="//GENERALDECLAIR/GENERALDECLAIR_ITEM">
				<xsl:variable name="IdAirGenDcl" select="../@id"/>
				<xsl:variable name="GdclaPos" select="position()"/>
				<xsl:variable name="GdclaType" select="../@ctmtd:CfgName"/>
				<xsl:variable name="CustomCode" select="CustomCode"/>
				<xsl:if test="string-length($CustomCode)>3 and substring($CustomCode,string-length($CustomCode)-2,3)='000' and $CustomCode!='00000000'">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Получателем документов может быть только таможенный пост. В генеральной декларации указан код таможни.'"/>
						<xsl:with-param name="DocId" select="@id"/>
						<xsl:with-param name="PathErr" select="'GENERALDECLAIR/GENERALDECLAIR_ITEM/CustomCode'"/>
						<xsl:with-param name="TypeDoc" select="$GdclaType"/>
						<xsl:with-param name="PosPkg" select="$GdclaPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="$CustomCode!='10700001' and ((string-length($CustomCode)>3 and substring($CustomCode,string-length($CustomCode)-2,3)!='000')  or $CustomCode='00000000')">
					<xsl:variable name="CustName" select="document('../../../NSI/TranspNSIXml.xml')//Customs_ITEM[Code=$CustomCode]/Name"/>
					<xsl:if test="string-length($CustName)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'В генеральной декларации указан не существующий код таможенного поста.'"/>
							<xsl:with-param name="DocId" select="@id"/>
							<xsl:with-param name="PathErr" select="'GENERALDECLAIR/GENERALDECLAIR_ITEM/CustomCode'"/>
							<xsl:with-param name="TypeDoc" select="$GdclaType"/>
							<xsl:with-param name="PosPkg" select="$GdclaPos"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
				<xsl:if test="string-length(FlNumber)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Генеральная авиа декларация с не заполненным полем Номер рейса.'"/>
						<xsl:with-param name="DocId" select="$IdAirGenDcl"/>
						<xsl:with-param name="PathErr" select="'GENERALDECLAIR/GENERALDECLAIR_ITEM/FlNumber'"/>
						<xsl:with-param name="TypeDoc" select="$GdclaType"/>
						<xsl:with-param name="PosPkg" select="$GdclaPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(FlDate)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Генеральная авиа декларация с не заполненным полем Дата рейса.'"/>
						<xsl:with-param name="DocId" select="$IdAirGenDcl"/>
						<xsl:with-param name="PathErr" select="'GENERALDECLAIR/GENERALDECLAIR_ITEM/FlDate'"/>
						<xsl:with-param name="TypeDoc" select="$GdclaType"/>
						<xsl:with-param name="PosPkg" select="$GdclaPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(AirplaneRegNumber)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Генеральная авиа декларация с не заполненным полем Бортовой номер воздушного судна.'"/>
						<xsl:with-param name="DocId" select="$IdAirGenDcl"/>
						<xsl:with-param name="PathErr" select="'GENERALDECLAIR/GENERALDECLAIR_ITEM/AirplaneRegNumber'"/>
						<xsl:with-param name="TypeDoc" select="$GdclaType"/>
						<xsl:with-param name="PosPkg" select="$GdclaPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(DepartureAirport_IATACode)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ Генеральная авиа декларация с не заполненным полем Код ИАТА аэропорта отправления.'"/>
						<xsl:with-param name="DocId" select="$IdAirGenDcl"/>
						<xsl:with-param name="PathErr" select="'GENERALDECLAIR/GENERALDECLAIR_ITEM/DepartureAirport_IATACode'"/>
						<xsl:with-param name="TypeDoc" select="$GdclaType"/>
						<xsl:with-param name="PosPkg" select="$GdclaPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(DepartureAirport_IATACode)>0">
					<xsl:variable name="IATACodeNsi" select="DepartureAirport_IATACode"/>
					<xsl:if test="count(document('../../../NSI/AirNsiXml.xml')//AIRPORTS_ITEM[IATA=$IATACodeNsi])=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ Генеральная авиа декларация, в которой в поле Код ИАТА аэропорта отправления указан код ИАТА, отсутствующий в справочнике.'"/>
							<xsl:with-param name="DocId" select="$IdAirGenDcl"/>
							<xsl:with-param name="PathErr" select="'GENERALDECLAIR/GENERALDECLAIR_ITEM/DepartureAirport_IATACode'"/>
							<xsl:with-param name="TypeDoc" select="$GdclaType"/>
							<xsl:with-param name="PosPkg" select="$GdclaPos"/>
							<xsl:with-param name="Category" select="'WARNING'"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
			</xsl:for-each>	
		</ResultInformation>
	</xsl:template>
	<xsl:template name="ErrorNode">
		<xsl:param name="MessErr"/>
		<xsl:param name="DocId"/>
		<xsl:param name="PathErr"/>
		<xsl:param name="Category"/>
		<xsl:param name="Num"/>
		<xsl:param name="TypeDoc"/>
		<xsl:param name="PosPkg"/>
		<xsl:variable name="Cat">
			<xsl:choose>
				<xsl:when test="string-length($Category)=0">ERROR</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$Category"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<RESULTINFORMATION_ITEM xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<ResultDescription><xsl:value-of select="$MessErr"/></ResultDescription>
			<ResultIdDocument><xsl:value-of select="$DocId"/></ResultIdDocument>
			<ResultTypeDocument><xsl:value-of select="$TypeDoc"/></ResultTypeDocument>
			<ResultPosInPkgDocument><xsl:value-of select="$PosPkg"/></ResultPosInPkgDocument>
			<ResultPathNode><xsl:value-of select="$PathErr"/></ResultPathNode>
			<ResultCategory><xsl:value-of select="$Cat"/></ResultCategory>
			<DocumentNumber><xsl:value-of select="$Num"/></DocumentNumber>
		</RESULTINFORMATION_ITEM>
	</xsl:template>
</xsl:stylesheet>
